/// Use this class as an annotation to define a class to be cloneable
/// so the the code generator can generate the boilerplate code for it
class Cloneable {
  /// If true all synthetic fields will not be taken into account when cloning.
  /// (Synthetic fields are those represented by set and get definitions)
  final bool? ignoreSynthetic;

  /// If true an extension will be generated on Class with a clone() function
  ///
  /// Default: true
  final bool? generateCloneExtension;

  /// Indicates that an empty List, Set, Map or Iterable to be considered
  /// as a null value when deciding clone from newData or keep currentData.
  /// Default: true
  final bool? considerEmptyCollectionAsNull;

  const Cloneable({
    this.ignoreSynthetic,
    this.generateCloneExtension,
    this.considerEmptyCollectionAsNull,
  });
}
