/// Use this class as an annotation to define a class to be able to copyWith
/// so the the code generator can generate the boilerplate code for it
class CopyWith {
  /// If true all synthetic fields will not be taken into account when cloning.
  /// (Synthetic fields are those represented by set and get definitions)
  ///
  /// Default: false
  final bool? ignoreSynthetic;

  /// Include private fields in copyWith function.
  ///
  /// Default: false
  final bool? includePrivateFields;

  /// If true the fields will not be passed in constructor, otherwise will be set
  /// directly.
  /// Default: false
  final bool? avoidConstructor;

  /// If true all nullable fields would get the value from copy without any null
  /// validation.
  ///
  /// e.g:
  /// When using allowNullable = false
  /// fieldX = newFieldX != null ? newFieldX : fieldX
  ///
  /// When using allowNullable = true
  /// fieldX = newFieldX
  ///
  /// default: false
  final bool? allowNullable;

  /// Indicates that an empty List, Set, Map or Iterable to be considered
  /// as a null value when deciding copyWith from newData or keep currentData.
  /// Default: true
  final bool? considerEmptyCollectionAsNull;

  const CopyWith({
    this.ignoreSynthetic,
    this.includePrivateFields,
    this.avoidConstructor,
    this.allowNullable,
    this.considerEmptyCollectionAsNull,
  });
}
