/// Use this class as an annotation to define a class to be differentiable
/// so the the code generator can generate the boilerplate code for it.
/// IMPORTANT: make sure you implement a proper == function for each field
/// in your class, the generator compares each field to check for differences
class Differentiable {
  /// If true all synthetic fields will not be taken into account when checking
  /// if a field is different
  /// (Synthetic fields are those represented by set and get definitions)
  final bool? ignoreSynthetic;

  /// If true an extension will be generated on Class with a diff() function
  ///
  /// Default: true
  final bool? generateDiffExtension;

  const Differentiable({
    this.ignoreSynthetic,
    this.generateDiffExtension,
  });
}
